@@ -326,7 +326,7 @@ on_view_action_activated (GSimpleAction *action,
                           gpointer       user_data)
 {
   GcalWindow *window = GCAL_WINDOW (user_data);
-  guint view;
+  gint32 view;
 
   view = g_variant_get_int32 (param);
 
@@ -702,7 +702,7 @@ set_new_event_mode (GcalWindow *window,
   /* for now we relaunch the new-event widget */
   if (!enabled && gtk_widget_is_visible (window->quick_add_popover))
     {
-      gtk_widget_set_visible (window->quick_add_popover, FALSE);
+      gtk_popover_popdown (GTK_POPOVER (window->quick_add_popover));
     }
 }
 
@@ -750,7 +750,7 @@ show_new_event_widget (GcalView   *view,
   rect.height = 1;
 
   gtk_popover_set_pointing_to (GTK_POPOVER (window->quick_add_popover), &rect);
-  gtk_widget_show (window->quick_add_popover);
+  gtk_popover_popup (GTK_POPOVER (window->quick_add_popover));
 }
 
 static void
@@ -1102,6 +1102,7 @@ edit_dialog_closed (GtkDialog *dialog,
   event = gcal_edit_dialog_get_event (edit_dialog);
   view = GCAL_VIEW (window->views[window->active_view]);
 
+  gcal_edit_dialog_set_event (edit_dialog, NULL);
   gtk_widget_hide (GTK_WIDGET (dialog));
 
   switch (response)
